;******************************************************************************;
;                                                                              ;
;  AUTOPLOT.LSP  v1.0                       (c) Copyright 1993 Bret Young      ;
;                                                  All Rights Reserved         ;
;                                                                              ;
;                                                                              ;
;  ABSTRACT                                                                    ;
;                                                                              ;
;    AUTOPLOT will plot to your configured plotter(s)/file(s) all items        ;
;    surrounded by the block "BLKNAME".  By creating multiple                  ;
;    (paperspace or modelspace) views of your drawing within one file,         ;
;    and surrounding each with "BLKNAME", you can automatically print          ;
;    all the pages (views) of your drawing.                                    ;
;                                                                              ;
;    If the plotter configuration picked contains the string "fax" then        ;
;    the batch file PCX2XCP will be executed to call PCXREV to reverse         ;
;    the colors.                                                               ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;  DISCLAIMER                                                                  ;
;                                                                              ;
;    This software is sold "as is" without express or implied                  ;
;    warranty. In no event shall the author be liable to you for any           ;
;    damages, including any lost profits, lost savings, or other               ;
;    incidental or consequential damages arising out of the use of or          ;
;    inability to use this program, even if the author has been                ;
;    advised of the possibility of such damages, or for any claim by           ;
;    any other party.                                                          ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;  SHAREWARE                                                                   ;
;                                                                              ;
;    AUTOPLOT was written by Bret Young and is distributed as shareware.       ;
;    This program is NOT public domain.  You have the opportunity to           ;
;    try this program for 15 days. If you find it useful and intend to         ;
;    use it further, please send $10 to:                                       ;
;                                                                              ;
;      Bret Young                                                              ;
;      1081 Lorne Way                                                          ;
;      Sunnyvale, CA 94087                                                     ;
;                                                                              ;
;                                                                              ;
;    Remember, shareware will only be around as long as YOU support it!        ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;  SUGGESTIONS                                                                 ;
;                                                                              ;
;    I'm interested in your comments and suggestions on AUTOPLOT,              ;
;    Please fax them to me at (408) 249 3435.                                  ;
;                                                                              ;
;    You don't have a fax machine?  OK, then mail your comments to me          ;
;    at the address above.  If you'd like a reply, please include a            ;
;    stamped, self-addressed envelope.                                         ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;  PERMISSION TO COPY                                                          ;
;                                                                              ;
;    Individuals, clubs, and other organizations are granted                   ;
;    permission by the author to freely copy and distribute this               ;
;    program and documentation so long as:                                     ;
;                                                                              ;
;      1. There is no charge for the software or documentation.                ;
;      2. The program or its documentation are not modified in any way.        ;
;      3. All files are distributed together.  No file may be deleted.         ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;  BACKGROUND                                                                  ;
;                                                                              ;
;    In creating drawings that required multiple 8.5x11 pages to               ;
;    complete all the detail, I found myself spending too much time            ;
;    sitting at the computer identifying where the corners of the              ;
;    window were for plotting each page of the drawing file.  Now, I           ;
;    run this program and when it's done, I can initiate faxing the            ;
;    drawing pages to multiple destinations and return to AutoCAD while        ;
;    the fax program works in the background.                                  ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
; IMPLEMETATION                                                                ;
;                                                                              ;
;     This program works only with AutoCAD R12.  If you need a version         ;
;     that works similiarly with R10 or R11, (and have a copy of Hijaak),      ;
;     please register and request a R10 version.                               ;
;                                                                              ;
;                                                                              ;
;     Here's what to do:                                                       ;
;                                                                              ;
;       1.  In order for this program to select the correct plotter            ;
;           configuration, you must either:                                    ;
;                                                                              ;
;               Use the AutoCAD12 "config" command to rename the               ;
;               plotter configuration to "FAX File" and/or "LaserJet           ;
;               File" (case sensitive)                                         ;
;                                                                              ;
;                              OR:                                             ;
;                                                                              ;
;               Search the program section of this file for "FAX File"         ;
;               and "LaserJet File" and rename them to configurations          ;
;               you presently have on your setup (case sensitive).             ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;       2.  Configure the plotter you plan on naming "FAX File" to             ;
;           AutoCAD's raster export (11).  Select ZSoft's PCX (6),             ;
;           monochrome, and "other" for size.  When asked if you wish          ;
;           to change anything, respond "yes".  Proceed to select the          ;
;           image size.  I've found that 1600,2100 works well with my          ;
;           fax software and page size of 8.0 x 10.5.  You may find            ;
;           that this should be decreased slightly to 1590,2090.               ;
;                                                                              ;
;                                                                              ;
;       3.  Add the following statement to your ACAD.PGP file:                 ;
;                                                                              ;
;               PCX,PCX2XCP,    0,,4                                           ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;       4.  Copy PCXREV.EXE and the batch file PCX2XCP.BAT to a                ;
;           directory in your path                                             ;
;                                                                              ;
;           Note:  PCXREV.EXE reverses the colors of AutoCAD's PCX             ;
;                  raster export file.  Registration of the AUTOPLOT           ;
;                  program includes the PCXREV program.                        ;                                            ;
;                                                                              ;
;                                                                              ;
;                                                                              ;
;******************************************************************************;


(defun AUTOPLOT_ERR (s)                 ; If an error (such as CTRL-C) occurs
   (if (/= s "Function cancelled")
       (progn
         (princ (strcat "\nError: " s))
         (setvar "CMDDIA" 1)
       );progn
   );if
   (if olderr (setq *error* olderr))  ; Restore old *error* handler
   (princ)
)
;
;
  (defun CLEAN (POINTLIST / N MBR) ;replaces nil in POINTLIST with first non nil atom in POINTLLIST
    (setq N 0 MBR nil)
      (while (eq MBR nil)
        (setq MBR (nth N POINTLIST)
                N (1+ N)
        );setq
      );while
    (setq POINTLIST (subst MBR nil POINTLIST))
  );defun CLEAN
;
;
(defun C:AUTOPLOT ()
;
;
  (setq olderr  *error*                 ; Save error routine
       *error* AUTOPLOT_ERR             ; Substitute ours
       BLKNAME (getstring "Name of page border? <PAGE>: ")  ;get page outline
       BLKNAME (if (eq BLKNAME "") "PAGE" BLKNAME)          ;default to "page"
        POINTX (list ) POINTY (list )                       ;initialize
       FEATURE (cdr (assoc '-2 (tblsearch "BLOCK" BLKNAME)));find page outline in blocktable
       PLTRID (strcase (getstring "FAX or LaserJet? : "))
       PLTRID (cond
                 ((wcmatch PLTRID "F*") "FAX File")
                 ((wcmatch PLTRID "L*") "LaserJet File")
                 ((wcmatch PLTRID "*")  "FAX File")
               );cond
  );setq
  (setvar "PLOTID" PLTRID)
;
;                                     ;find all points in page outline
  (while (entnext FEATURE)
    (setq POINTX (cons (cadr  (assoc '10 (entget FEATURE))) POINTX)
          POINTX (cons (cadr  (assoc '11 (entget FEATURE))) POINTX)
          POINTY (cons (caddr (assoc '10 (entget FEATURE))) POINTY)
          POINTY (cons (caddr (assoc '11 (entget FEATURE))) POINTY)
         FEATURE (entnext FEATURE)
    );setq
  );while
;
;                                     ;set min and max points of page outline
  (setq P1 (list (apply 'min (CLEAN POINTX)) (apply 'min (CLEAN POINTY)) 0)
        P2 (list (apply 'max (CLEAN POINTX)) (apply 'max (CLEAN POINTY)) 0)
        PG 0
  );setq
  (setvar "CMDDIA" 0)
;
;                                     ;set scale and position of each insertion
;                                     ;point of the page outline, then plot
  (while (< PG (sslength (setq DWG (ssget "X" (list (cons 2 BLKNAME))))))
    (setq   SCALE (cdr (assoc '41 (entget (ssname DWG PG))))
            SCALE (list SCALE SCALE SCALE)
              POS (cdr (assoc '10 (entget (ssname DWG PG))))
               LL (mapcar '+ POS (mapcar '* SCALE P1))
               UR (mapcar '+ POS (mapcar '* SCALE P2))
      PLTFILENAME (strcat (rtos (sslength DWG) 2 0) "-" (rtos (1+ PG) 2 0))
    );setq
    (command "PLOT" "W" LL UR "N" PLTFILENAME)
    (setq PG (1+ PG))
  );while
;
;
  (setvar "CMDDIA" 1)
;
  (if (wcmatch (strcase PLTRID) "*FAX*")
    (command "PCX")
  );if
)
